package com.srs.stureg.service;

import java.util.List;
import com.srs.stureg.domain.SrsDormSelect;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author srs
 * @date 2023-07-24
 */
public interface ISrsDormSelectService 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public SrsDormSelect selectSrsDormSelectById(Long id);

    /**
     * 根据学号查询可选宿舍
     * @param stuNo
     * @return
     */
    public  List<SrsDormSelect> selectSrsDormSelectBystuNo(String stuNo);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param srsDormSelect 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<SrsDormSelect> selectSrsDormSelectList(SrsDormSelect srsDormSelect);

    /**
     * 新增【请填写功能名称】
     * 
     * @param srsDormSelect 【请填写功能名称】
     * @return 结果
     */
    public int insertSrsDormSelect(SrsDormSelect srsDormSelect);

    /**
     * 修改【请填写功能名称】
     * 
     * @param srsDormSelect 【请填写功能名称】
     * @return 结果
     */
    public int updateSrsDormSelect(SrsDormSelect srsDormSelect);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteSrsDormSelectByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteSrsDormSelectById(Long id);
}
